# giwaxs_gui
### A graphical tool for GIWAXS data analysis.

giwaxs_gui contains all the basic functionality for 
the analysis of 2D diffraction images with circular symmetry. 
In particular, it focuses on grazing-incidence wide-angle scattering
data and its specific needs.
